#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class KoubeiMemberDataOauthQueryModel(object):

    def __init__(self):
        self._auth_type = None
        self._code = None
        self._ext_info = None

    @property
    def auth_type(self):
        return self._auth_type

    @auth_type.setter
    def auth_type(self, value):
        self._auth_type = value
    @property
    def code(self):
        return self._code

    @code.setter
    def code(self, value):
        self._code = value
    @property
    def ext_info(self):
        return self._ext_info

    @ext_info.setter
    def ext_info(self, value):
        self._ext_info = value


    def to_alipay_dict(self):
        params = dict()
        if self.auth_type:
            if hasattr(self.auth_type, 'to_alipay_dict'):
                params['auth_type'] = self.auth_type.to_alipay_dict()
            else:
                params['auth_type'] = self.auth_type
        if self.code:
            if hasattr(self.code, 'to_alipay_dict'):
                params['code'] = self.code.to_alipay_dict()
            else:
                params['code'] = self.code
        if self.ext_info:
            if hasattr(self.ext_info, 'to_alipay_dict'):
                params['ext_info'] = self.ext_info.to_alipay_dict()
            else:
                params['ext_info'] = self.ext_info
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = KoubeiMemberDataOauthQueryModel()
        if 'auth_type' in d:
            o.auth_type = d['auth_type']
        if 'code' in d:
            o.code = d['code']
        if 'ext_info' in d:
            o.ext_info = d['ext_info']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.DetectCheckLabel import DetectCheckLabel


class InfoSecAnalyzeSyncResult(object):

    def __init__(self):
        self._data_id = None
        self._detect_check_labels = None
        self._suggestion = None
        self._task_id = None

    @property
    def data_id(self):
        return self._data_id

    @data_id.setter
    def data_id(self, value):
        self._data_id = value
    @property
    def detect_check_labels(self):
        return self._detect_check_labels

    @detect_check_labels.setter
    def detect_check_labels(self, value):
        if isinstance(value, list):
            self._detect_check_labels = list()
            for i in value:
                if isinstance(i, DetectCheckLabel):
                    self._detect_check_labels.append(i)
                else:
                    self._detect_check_labels.append(DetectCheckLabel.from_alipay_dict(i))
    @property
    def suggestion(self):
        return self._suggestion

    @suggestion.setter
    def suggestion(self, value):
        self._suggestion = value
    @property
    def task_id(self):
        return self._task_id

    @task_id.setter
    def task_id(self, value):
        self._task_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.data_id:
            if hasattr(self.data_id, 'to_alipay_dict'):
                params['data_id'] = self.data_id.to_alipay_dict()
            else:
                params['data_id'] = self.data_id
        if self.detect_check_labels:
            if isinstance(self.detect_check_labels, list):
                for i in range(0, len(self.detect_check_labels)):
                    element = self.detect_check_labels[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.detect_check_labels[i] = element.to_alipay_dict()
            if hasattr(self.detect_check_labels, 'to_alipay_dict'):
                params['detect_check_labels'] = self.detect_check_labels.to_alipay_dict()
            else:
                params['detect_check_labels'] = self.detect_check_labels
        if self.suggestion:
            if hasattr(self.suggestion, 'to_alipay_dict'):
                params['suggestion'] = self.suggestion.to_alipay_dict()
            else:
                params['suggestion'] = self.suggestion
        if self.task_id:
            if hasattr(self.task_id, 'to_alipay_dict'):
                params['task_id'] = self.task_id.to_alipay_dict()
            else:
                params['task_id'] = self.task_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = InfoSecAnalyzeSyncResult()
        if 'data_id' in d:
            o.data_id = d['data_id']
        if 'detect_check_labels' in d:
            o.detect_check_labels = d['detect_check_labels']
        if 'suggestion' in d:
            o.suggestion = d['suggestion']
        if 'task_id' in d:
            o.task_id = d['task_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class PremiumPaymentDTO(object):

    def __init__(self):
        self._in_account_name = None
        self._in_account_no = None
        self._in_account_type = None
        self._ins_pre_order_id = None
        self._out_account_name = None
        self._out_account_no = None
        self._out_account_type = None
        self._pay_bill_no = None
        self._pay_channel = None
        self._pay_fee = None
        self._pay_order_no = None
        self._pay_out_biz_no = None
        self._pay_time = None
        self._product_code = None
        self._quote_id = None
        self._recommend_flow_id = None

    @property
    def in_account_name(self):
        return self._in_account_name

    @in_account_name.setter
    def in_account_name(self, value):
        self._in_account_name = value
    @property
    def in_account_no(self):
        return self._in_account_no

    @in_account_no.setter
    def in_account_no(self, value):
        self._in_account_no = value
    @property
    def in_account_type(self):
        return self._in_account_type

    @in_account_type.setter
    def in_account_type(self, value):
        self._in_account_type = value
    @property
    def ins_pre_order_id(self):
        return self._ins_pre_order_id

    @ins_pre_order_id.setter
    def ins_pre_order_id(self, value):
        self._ins_pre_order_id = value
    @property
    def out_account_name(self):
        return self._out_account_name

    @out_account_name.setter
    def out_account_name(self, value):
        self._out_account_name = value
    @property
    def out_account_no(self):
        return self._out_account_no

    @out_account_no.setter
    def out_account_no(self, value):
        self._out_account_no = value
    @property
    def out_account_type(self):
        return self._out_account_type

    @out_account_type.setter
    def out_account_type(self, value):
        self._out_account_type = value
    @property
    def pay_bill_no(self):
        return self._pay_bill_no

    @pay_bill_no.setter
    def pay_bill_no(self, value):
        self._pay_bill_no = value
    @property
    def pay_channel(self):
        return self._pay_channel

    @pay_channel.setter
    def pay_channel(self, value):
        self._pay_channel = value
    @property
    def pay_fee(self):
        return self._pay_fee

    @pay_fee.setter
    def pay_fee(self, value):
        self._pay_fee = value
    @property
    def pay_order_no(self):
        return self._pay_order_no

    @pay_order_no.setter
    def pay_order_no(self, value):
        self._pay_order_no = value
    @property
    def pay_out_biz_no(self):
        return self._pay_out_biz_no

    @pay_out_biz_no.setter
    def pay_out_biz_no(self, value):
        self._pay_out_biz_no = value
    @property
    def pay_time(self):
        return self._pay_time

    @pay_time.setter
    def pay_time(self, value):
        self._pay_time = value
    @property
    def product_code(self):
        return self._product_code

    @product_code.setter
    def product_code(self, value):
        self._product_code = value
    @property
    def quote_id(self):
        return self._quote_id

    @quote_id.setter
    def quote_id(self, value):
        self._quote_id = value
    @property
    def recommend_flow_id(self):
        return self._recommend_flow_id

    @recommend_flow_id.setter
    def recommend_flow_id(self, value):
        self._recommend_flow_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.in_account_name:
            if hasattr(self.in_account_name, 'to_alipay_dict'):
                params['in_account_name'] = self.in_account_name.to_alipay_dict()
            else:
                params['in_account_name'] = self.in_account_name
        if self.in_account_no:
            if hasattr(self.in_account_no, 'to_alipay_dict'):
                params['in_account_no'] = self.in_account_no.to_alipay_dict()
            else:
                params['in_account_no'] = self.in_account_no
        if self.in_account_type:
            if hasattr(self.in_account_type, 'to_alipay_dict'):
                params['in_account_type'] = self.in_account_type.to_alipay_dict()
            else:
                params['in_account_type'] = self.in_account_type
        if self.ins_pre_order_id:
            if hasattr(self.ins_pre_order_id, 'to_alipay_dict'):
                params['ins_pre_order_id'] = self.ins_pre_order_id.to_alipay_dict()
            else:
                params['ins_pre_order_id'] = self.ins_pre_order_id
        if self.out_account_name:
            if hasattr(self.out_account_name, 'to_alipay_dict'):
                params['out_account_name'] = self.out_account_name.to_alipay_dict()
            else:
                params['out_account_name'] = self.out_account_name
        if self.out_account_no:
            if hasattr(self.out_account_no, 'to_alipay_dict'):
                params['out_account_no'] = self.out_account_no.to_alipay_dict()
            else:
                params['out_account_no'] = self.out_account_no
        if self.out_account_type:
            if hasattr(self.out_account_type, 'to_alipay_dict'):
                params['out_account_type'] = self.out_account_type.to_alipay_dict()
            else:
                params['out_account_type'] = self.out_account_type
        if self.pay_bill_no:
            if hasattr(self.pay_bill_no, 'to_alipay_dict'):
                params['pay_bill_no'] = self.pay_bill_no.to_alipay_dict()
            else:
                params['pay_bill_no'] = self.pay_bill_no
        if self.pay_channel:
            if hasattr(self.pay_channel, 'to_alipay_dict'):
                params['pay_channel'] = self.pay_channel.to_alipay_dict()
            else:
                params['pay_channel'] = self.pay_channel
        if self.pay_fee:
            if hasattr(self.pay_fee, 'to_alipay_dict'):
                params['pay_fee'] = self.pay_fee.to_alipay_dict()
            else:
                params['pay_fee'] = self.pay_fee
        if self.pay_order_no:
            if hasattr(self.pay_order_no, 'to_alipay_dict'):
                params['pay_order_no'] = self.pay_order_no.to_alipay_dict()
            else:
                params['pay_order_no'] = self.pay_order_no
        if self.pay_out_biz_no:
            if hasattr(self.pay_out_biz_no, 'to_alipay_dict'):
                params['pay_out_biz_no'] = self.pay_out_biz_no.to_alipay_dict()
            else:
                params['pay_out_biz_no'] = self.pay_out_biz_no
        if self.pay_time:
            if hasattr(self.pay_time, 'to_alipay_dict'):
                params['pay_time'] = self.pay_time.to_alipay_dict()
            else:
                params['pay_time'] = self.pay_time
        if self.product_code:
            if hasattr(self.product_code, 'to_alipay_dict'):
                params['product_code'] = self.product_code.to_alipay_dict()
            else:
                params['product_code'] = self.product_code
        if self.quote_id:
            if hasattr(self.quote_id, 'to_alipay_dict'):
                params['quote_id'] = self.quote_id.to_alipay_dict()
            else:
                params['quote_id'] = self.quote_id
        if self.recommend_flow_id:
            if hasattr(self.recommend_flow_id, 'to_alipay_dict'):
                params['recommend_flow_id'] = self.recommend_flow_id.to_alipay_dict()
            else:
                params['recommend_flow_id'] = self.recommend_flow_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = PremiumPaymentDTO()
        if 'in_account_name' in d:
            o.in_account_name = d['in_account_name']
        if 'in_account_no' in d:
            o.in_account_no = d['in_account_no']
        if 'in_account_type' in d:
            o.in_account_type = d['in_account_type']
        if 'ins_pre_order_id' in d:
            o.ins_pre_order_id = d['ins_pre_order_id']
        if 'out_account_name' in d:
            o.out_account_name = d['out_account_name']
        if 'out_account_no' in d:
            o.out_account_no = d['out_account_no']
        if 'out_account_type' in d:
            o.out_account_type = d['out_account_type']
        if 'pay_bill_no' in d:
            o.pay_bill_no = d['pay_bill_no']
        if 'pay_channel' in d:
            o.pay_channel = d['pay_channel']
        if 'pay_fee' in d:
            o.pay_fee = d['pay_fee']
        if 'pay_order_no' in d:
            o.pay_order_no = d['pay_order_no']
        if 'pay_out_biz_no' in d:
            o.pay_out_biz_no = d['pay_out_biz_no']
        if 'pay_time' in d:
            o.pay_time = d['pay_time']
        if 'product_code' in d:
            o.product_code = d['product_code']
        if 'quote_id' in d:
            o.quote_id = d['quote_id']
        if 'recommend_flow_id' in d:
            o.recommend_flow_id = d['recommend_flow_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class BusinessPermission(object):

    def __init__(self):
        self._domain = None
        self._permission_code = None
        self._source_permission_code = None

    @property
    def domain(self):
        return self._domain

    @domain.setter
    def domain(self, value):
        self._domain = value
    @property
    def permission_code(self):
        return self._permission_code

    @permission_code.setter
    def permission_code(self, value):
        self._permission_code = value
    @property
    def source_permission_code(self):
        return self._source_permission_code

    @source_permission_code.setter
    def source_permission_code(self, value):
        self._source_permission_code = value


    def to_alipay_dict(self):
        params = dict()
        if self.domain:
            if hasattr(self.domain, 'to_alipay_dict'):
                params['domain'] = self.domain.to_alipay_dict()
            else:
                params['domain'] = self.domain
        if self.permission_code:
            if hasattr(self.permission_code, 'to_alipay_dict'):
                params['permission_code'] = self.permission_code.to_alipay_dict()
            else:
                params['permission_code'] = self.permission_code
        if self.source_permission_code:
            if hasattr(self.source_permission_code, 'to_alipay_dict'):
                params['source_permission_code'] = self.source_permission_code.to_alipay_dict()
            else:
                params['source_permission_code'] = self.source_permission_code
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = BusinessPermission()
        if 'domain' in d:
            o.domain = d['domain']
        if 'permission_code' in d:
            o.permission_code = d['permission_code']
        if 'source_permission_code' in d:
            o.source_permission_code = d['source_permission_code']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.BenefitUseLimitDTO import BenefitUseLimitDTO
from alipay.aop.api.domain.BenefitValidPeriodDTO import BenefitValidPeriodDTO
from alipay.aop.api.domain.BenefitUsageScopeDTO import BenefitUsageScopeDTO


class BenefitUseRuleDTO(object):

    def __init__(self):
        self._benefit_use_limit = None
        self._benefit_valid_period = None
        self._usage_scope = None

    @property
    def benefit_use_limit(self):
        return self._benefit_use_limit

    @benefit_use_limit.setter
    def benefit_use_limit(self, value):
        if isinstance(value, BenefitUseLimitDTO):
            self._benefit_use_limit = value
        else:
            self._benefit_use_limit = BenefitUseLimitDTO.from_alipay_dict(value)
    @property
    def benefit_valid_period(self):
        return self._benefit_valid_period

    @benefit_valid_period.setter
    def benefit_valid_period(self, value):
        if isinstance(value, BenefitValidPeriodDTO):
            self._benefit_valid_period = value
        else:
            self._benefit_valid_period = BenefitValidPeriodDTO.from_alipay_dict(value)
    @property
    def usage_scope(self):
        return self._usage_scope

    @usage_scope.setter
    def usage_scope(self, value):
        if isinstance(value, BenefitUsageScopeDTO):
            self._usage_scope = value
        else:
            self._usage_scope = BenefitUsageScopeDTO.from_alipay_dict(value)


    def to_alipay_dict(self):
        params = dict()
        if self.benefit_use_limit:
            if hasattr(self.benefit_use_limit, 'to_alipay_dict'):
                params['benefit_use_limit'] = self.benefit_use_limit.to_alipay_dict()
            else:
                params['benefit_use_limit'] = self.benefit_use_limit
        if self.benefit_valid_period:
            if hasattr(self.benefit_valid_period, 'to_alipay_dict'):
                params['benefit_valid_period'] = self.benefit_valid_period.to_alipay_dict()
            else:
                params['benefit_valid_period'] = self.benefit_valid_period
        if self.usage_scope:
            if hasattr(self.usage_scope, 'to_alipay_dict'):
                params['usage_scope'] = self.usage_scope.to_alipay_dict()
            else:
                params['usage_scope'] = self.usage_scope
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = BenefitUseRuleDTO()
        if 'benefit_use_limit' in d:
            o.benefit_use_limit = d['benefit_use_limit']
        if 'benefit_valid_period' in d:
            o.benefit_valid_period = d['benefit_valid_period']
        if 'usage_scope' in d:
            o.usage_scope = d['usage_scope']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.SlmAppInfo import SlmAppInfo
from alipay.aop.api.domain.CheckPointVO import CheckPointVO
from alipay.aop.api.domain.SlmArtifactInfo import SlmArtifactInfo
from alipay.aop.api.domain.SlmCaseErrorInfo import SlmCaseErrorInfo
from alipay.aop.api.domain.SlmDeviceInfo import SlmDeviceInfo
from alipay.aop.api.domain.SlmArtifactInfo import SlmArtifactInfo


class OneStopCheckTaskDetailDTO(object):

    def __init__(self):
        self._app_info = None
        self._auto_screen_cap = None
        self._case_ame = None
        self._case_desc = None
        self._check_points = None
        self._custom_log = None
        self._custom_screen_caps = None
        self._end_time = None
        self._error_info = None
        self._model = None
        self._result = None
        self._screenshot_list = None
        self._start_time = None
        self._task_id = None

    @property
    def app_info(self):
        return self._app_info

    @app_info.setter
    def app_info(self, value):
        if isinstance(value, SlmAppInfo):
            self._app_info = value
        else:
            self._app_info = SlmAppInfo.from_alipay_dict(value)
    @property
    def auto_screen_cap(self):
        return self._auto_screen_cap

    @auto_screen_cap.setter
    def auto_screen_cap(self, value):
        self._auto_screen_cap = value
    @property
    def case_ame(self):
        return self._case_ame

    @case_ame.setter
    def case_ame(self, value):
        self._case_ame = value
    @property
    def case_desc(self):
        return self._case_desc

    @case_desc.setter
    def case_desc(self, value):
        self._case_desc = value
    @property
    def check_points(self):
        return self._check_points

    @check_points.setter
    def check_points(self, value):
        if isinstance(value, list):
            self._check_points = list()
            for i in value:
                if isinstance(i, CheckPointVO):
                    self._check_points.append(i)
                else:
                    self._check_points.append(CheckPointVO.from_alipay_dict(i))
    @property
    def custom_log(self):
        return self._custom_log

    @custom_log.setter
    def custom_log(self, value):
        self._custom_log = value
    @property
    def custom_screen_caps(self):
        return self._custom_screen_caps

    @custom_screen_caps.setter
    def custom_screen_caps(self, value):
        if isinstance(value, list):
            self._custom_screen_caps = list()
            for i in value:
                if isinstance(i, SlmArtifactInfo):
                    self._custom_screen_caps.append(i)
                else:
                    self._custom_screen_caps.append(SlmArtifactInfo.from_alipay_dict(i))
    @property
    def end_time(self):
        return self._end_time

    @end_time.setter
    def end_time(self, value):
        self._end_time = value
    @property
    def error_info(self):
        return self._error_info

    @error_info.setter
    def error_info(self, value):
        if isinstance(value, SlmCaseErrorInfo):
            self._error_info = value
        else:
            self._error_info = SlmCaseErrorInfo.from_alipay_dict(value)
    @property
    def model(self):
        return self._model

    @model.setter
    def model(self, value):
        if isinstance(value, SlmDeviceInfo):
            self._model = value
        else:
            self._model = SlmDeviceInfo.from_alipay_dict(value)
    @property
    def result(self):
        return self._result

    @result.setter
    def result(self, value):
        self._result = value
    @property
    def screenshot_list(self):
        return self._screenshot_list

    @screenshot_list.setter
    def screenshot_list(self, value):
        if isinstance(value, list):
            self._screenshot_list = list()
            for i in value:
                if isinstance(i, SlmArtifactInfo):
                    self._screenshot_list.append(i)
                else:
                    self._screenshot_list.append(SlmArtifactInfo.from_alipay_dict(i))
    @property
    def start_time(self):
        return self._start_time

    @start_time.setter
    def start_time(self, value):
        self._start_time = value
    @property
    def task_id(self):
        return self._task_id

    @task_id.setter
    def task_id(self, value):
        self._task_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.app_info:
            if hasattr(self.app_info, 'to_alipay_dict'):
                params['app_info'] = self.app_info.to_alipay_dict()
            else:
                params['app_info'] = self.app_info
        if self.auto_screen_cap:
            if hasattr(self.auto_screen_cap, 'to_alipay_dict'):
                params['auto_screen_cap'] = self.auto_screen_cap.to_alipay_dict()
            else:
                params['auto_screen_cap'] = self.auto_screen_cap
        if self.case_ame:
            if hasattr(self.case_ame, 'to_alipay_dict'):
                params['case_ame'] = self.case_ame.to_alipay_dict()
            else:
                params['case_ame'] = self.case_ame
        if self.case_desc:
            if hasattr(self.case_desc, 'to_alipay_dict'):
                params['case_desc'] = self.case_desc.to_alipay_dict()
            else:
                params['case_desc'] = self.case_desc
        if self.check_points:
            if isinstance(self.check_points, list):
                for i in range(0, len(self.check_points)):
                    element = self.check_points[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.check_points[i] = element.to_alipay_dict()
            if hasattr(self.check_points, 'to_alipay_dict'):
                params['check_points'] = self.check_points.to_alipay_dict()
            else:
                params['check_points'] = self.check_points
        if self.custom_log:
            if hasattr(self.custom_log, 'to_alipay_dict'):
                params['custom_log'] = self.custom_log.to_alipay_dict()
            else:
                params['custom_log'] = self.custom_log
        if self.custom_screen_caps:
            if isinstance(self.custom_screen_caps, list):
                for i in range(0, len(self.custom_screen_caps)):
                    element = self.custom_screen_caps[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.custom_screen_caps[i] = element.to_alipay_dict()
            if hasattr(self.custom_screen_caps, 'to_alipay_dict'):
                params['custom_screen_caps'] = self.custom_screen_caps.to_alipay_dict()
            else:
                params['custom_screen_caps'] = self.custom_screen_caps
        if self.end_time:
            if hasattr(self.end_time, 'to_alipay_dict'):
                params['end_time'] = self.end_time.to_alipay_dict()
            else:
                params['end_time'] = self.end_time
        if self.error_info:
            if hasattr(self.error_info, 'to_alipay_dict'):
                params['error_info'] = self.error_info.to_alipay_dict()
            else:
                params['error_info'] = self.error_info
        if self.model:
            if hasattr(self.model, 'to_alipay_dict'):
                params['model'] = self.model.to_alipay_dict()
            else:
                params['model'] = self.model
        if self.result:
            if hasattr(self.result, 'to_alipay_dict'):
                params['result'] = self.result.to_alipay_dict()
            else:
                params['result'] = self.result
        if self.screenshot_list:
            if isinstance(self.screenshot_list, list):
                for i in range(0, len(self.screenshot_list)):
                    element = self.screenshot_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.screenshot_list[i] = element.to_alipay_dict()
            if hasattr(self.screenshot_list, 'to_alipay_dict'):
                params['screenshot_list'] = self.screenshot_list.to_alipay_dict()
            else:
                params['screenshot_list'] = self.screenshot_list
        if self.start_time:
            if hasattr(self.start_time, 'to_alipay_dict'):
                params['start_time'] = self.start_time.to_alipay_dict()
            else:
                params['start_time'] = self.start_time
        if self.task_id:
            if hasattr(self.task_id, 'to_alipay_dict'):
                params['task_id'] = self.task_id.to_alipay_dict()
            else:
                params['task_id'] = self.task_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = OneStopCheckTaskDetailDTO()
        if 'app_info' in d:
            o.app_info = d['app_info']
        if 'auto_screen_cap' in d:
            o.auto_screen_cap = d['auto_screen_cap']
        if 'case_ame' in d:
            o.case_ame = d['case_ame']
        if 'case_desc' in d:
            o.case_desc = d['case_desc']
        if 'check_points' in d:
            o.check_points = d['check_points']
        if 'custom_log' in d:
            o.custom_log = d['custom_log']
        if 'custom_screen_caps' in d:
            o.custom_screen_caps = d['custom_screen_caps']
        if 'end_time' in d:
            o.end_time = d['end_time']
        if 'error_info' in d:
            o.error_info = d['error_info']
        if 'model' in d:
            o.model = d['model']
        if 'result' in d:
            o.result = d['result']
        if 'screenshot_list' in d:
            o.screenshot_list = d['screenshot_list']
        if 'start_time' in d:
            o.start_time = d['start_time']
        if 'task_id' in d:
            o.task_id = d['task_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.PosDeviceInfoVO import PosDeviceInfoVO
from alipay.aop.api.domain.PosOrderInfoVO import PosOrderInfoVO


class KoubeiCateringPosOrderUploadModel(object):

    def __init__(self):
        self._pos_device_infos = None
        self._pos_order_infos = None
        self._source_type = None

    @property
    def pos_device_infos(self):
        return self._pos_device_infos

    @pos_device_infos.setter
    def pos_device_infos(self, value):
        if isinstance(value, list):
            self._pos_device_infos = list()
            for i in value:
                if isinstance(i, PosDeviceInfoVO):
                    self._pos_device_infos.append(i)
                else:
                    self._pos_device_infos.append(PosDeviceInfoVO.from_alipay_dict(i))
    @property
    def pos_order_infos(self):
        return self._pos_order_infos

    @pos_order_infos.setter
    def pos_order_infos(self, value):
        if isinstance(value, list):
            self._pos_order_infos = list()
            for i in value:
                if isinstance(i, PosOrderInfoVO):
                    self._pos_order_infos.append(i)
                else:
                    self._pos_order_infos.append(PosOrderInfoVO.from_alipay_dict(i))
    @property
    def source_type(self):
        return self._source_type

    @source_type.setter
    def source_type(self, value):
        self._source_type = value


    def to_alipay_dict(self):
        params = dict()
        if self.pos_device_infos:
            if isinstance(self.pos_device_infos, list):
                for i in range(0, len(self.pos_device_infos)):
                    element = self.pos_device_infos[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.pos_device_infos[i] = element.to_alipay_dict()
            if hasattr(self.pos_device_infos, 'to_alipay_dict'):
                params['pos_device_infos'] = self.pos_device_infos.to_alipay_dict()
            else:
                params['pos_device_infos'] = self.pos_device_infos
        if self.pos_order_infos:
            if isinstance(self.pos_order_infos, list):
                for i in range(0, len(self.pos_order_infos)):
                    element = self.pos_order_infos[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.pos_order_infos[i] = element.to_alipay_dict()
            if hasattr(self.pos_order_infos, 'to_alipay_dict'):
                params['pos_order_infos'] = self.pos_order_infos.to_alipay_dict()
            else:
                params['pos_order_infos'] = self.pos_order_infos
        if self.source_type:
            if hasattr(self.source_type, 'to_alipay_dict'):
                params['source_type'] = self.source_type.to_alipay_dict()
            else:
                params['source_type'] = self.source_type
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = KoubeiCateringPosOrderUploadModel()
        if 'pos_device_infos' in d:
            o.pos_device_infos = d['pos_device_infos']
        if 'pos_order_infos' in d:
            o.pos_order_infos = d['pos_order_infos']
        if 'source_type' in d:
            o.source_type = d['source_type']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayFundTransTobankTransferResponse(AlipayResponse):

    def __init__(self):
        super(AlipayFundTransTobankTransferResponse, self).__init__()
        self._arrival_time_end = None
        self._order_id = None
        self._out_biz_no = None

    @property
    def arrival_time_end(self):
        return self._arrival_time_end

    @arrival_time_end.setter
    def arrival_time_end(self, value):
        self._arrival_time_end = value
    @property
    def order_id(self):
        return self._order_id

    @order_id.setter
    def order_id(self, value):
        self._order_id = value
    @property
    def out_biz_no(self):
        return self._out_biz_no

    @out_biz_no.setter
    def out_biz_no(self, value):
        self._out_biz_no = value

    def parse_response_content(self, response_content):
        response = super(AlipayFundTransTobankTransferResponse, self).parse_response_content(response_content)
        if 'arrival_time_end' in response:
            self.arrival_time_end = response['arrival_time_end']
        if 'order_id' in response:
            self.order_id = response['order_id']
        if 'out_biz_no' in response:
            self.out_biz_no = response['out_biz_no']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class MemberInfo(object):

    def __init__(self):
        self._gender = None
        self._group_nick_name = None
        self._inviter_uid = None
        self._member_img = None
        self._nick_name = None
        self._uid = None

    @property
    def gender(self):
        return self._gender

    @gender.setter
    def gender(self, value):
        self._gender = value
    @property
    def group_nick_name(self):
        return self._group_nick_name

    @group_nick_name.setter
    def group_nick_name(self, value):
        self._group_nick_name = value
    @property
    def inviter_uid(self):
        return self._inviter_uid

    @inviter_uid.setter
    def inviter_uid(self, value):
        self._inviter_uid = value
    @property
    def member_img(self):
        return self._member_img

    @member_img.setter
    def member_img(self, value):
        self._member_img = value
    @property
    def nick_name(self):
        return self._nick_name

    @nick_name.setter
    def nick_name(self, value):
        self._nick_name = value
    @property
    def uid(self):
        return self._uid

    @uid.setter
    def uid(self, value):
        self._uid = value


    def to_alipay_dict(self):
        params = dict()
        if self.gender:
            if hasattr(self.gender, 'to_alipay_dict'):
                params['gender'] = self.gender.to_alipay_dict()
            else:
                params['gender'] = self.gender
        if self.group_nick_name:
            if hasattr(self.group_nick_name, 'to_alipay_dict'):
                params['group_nick_name'] = self.group_nick_name.to_alipay_dict()
            else:
                params['group_nick_name'] = self.group_nick_name
        if self.inviter_uid:
            if hasattr(self.inviter_uid, 'to_alipay_dict'):
                params['inviter_uid'] = self.inviter_uid.to_alipay_dict()
            else:
                params['inviter_uid'] = self.inviter_uid
        if self.member_img:
            if hasattr(self.member_img, 'to_alipay_dict'):
                params['member_img'] = self.member_img.to_alipay_dict()
            else:
                params['member_img'] = self.member_img
        if self.nick_name:
            if hasattr(self.nick_name, 'to_alipay_dict'):
                params['nick_name'] = self.nick_name.to_alipay_dict()
            else:
                params['nick_name'] = self.nick_name
        if self.uid:
            if hasattr(self.uid, 'to_alipay_dict'):
                params['uid'] = self.uid.to_alipay_dict()
            else:
                params['uid'] = self.uid
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = MemberInfo()
        if 'gender' in d:
            o.gender = d['gender']
        if 'group_nick_name' in d:
            o.group_nick_name = d['group_nick_name']
        if 'inviter_uid' in d:
            o.inviter_uid = d['inviter_uid']
        if 'member_img' in d:
            o.member_img = d['member_img']
        if 'nick_name' in d:
            o.nick_name = d['nick_name']
        if 'uid' in d:
            o.uid = d['uid']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.CreditRateNoAuth import CreditRateNoAuth
from alipay.aop.api.domain.CreditRatePartialAuth import CreditRatePartialAuth


class CreateExtInfo(object):

    def __init__(self):
        self._cr_no_auth = None
        self._cr_partial_auth = None

    @property
    def cr_no_auth(self):
        return self._cr_no_auth

    @cr_no_auth.setter
    def cr_no_auth(self, value):
        if isinstance(value, CreditRateNoAuth):
            self._cr_no_auth = value
        else:
            self._cr_no_auth = CreditRateNoAuth.from_alipay_dict(value)
    @property
    def cr_partial_auth(self):
        return self._cr_partial_auth

    @cr_partial_auth.setter
    def cr_partial_auth(self, value):
        if isinstance(value, CreditRatePartialAuth):
            self._cr_partial_auth = value
        else:
            self._cr_partial_auth = CreditRatePartialAuth.from_alipay_dict(value)


    def to_alipay_dict(self):
        params = dict()
        if self.cr_no_auth:
            if hasattr(self.cr_no_auth, 'to_alipay_dict'):
                params['cr_no_auth'] = self.cr_no_auth.to_alipay_dict()
            else:
                params['cr_no_auth'] = self.cr_no_auth
        if self.cr_partial_auth:
            if hasattr(self.cr_partial_auth, 'to_alipay_dict'):
                params['cr_partial_auth'] = self.cr_partial_auth.to_alipay_dict()
            else:
                params['cr_partial_auth'] = self.cr_partial_auth
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = CreateExtInfo()
        if 'cr_no_auth' in d:
            o.cr_no_auth = d['cr_no_auth']
        if 'cr_partial_auth' in d:
            o.cr_partial_auth = d['cr_partial_auth']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.MiniAppHistoryInfo import MiniAppHistoryInfo


class AlipayOpenMiniMiniappHistoryQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayOpenMiniMiniappHistoryQueryResponse, self).__init__()
        self._mini_app_history_infos = None

    @property
    def mini_app_history_infos(self):
        return self._mini_app_history_infos

    @mini_app_history_infos.setter
    def mini_app_history_infos(self, value):
        if isinstance(value, list):
            self._mini_app_history_infos = list()
            for i in value:
                if isinstance(i, MiniAppHistoryInfo):
                    self._mini_app_history_infos.append(i)
                else:
                    self._mini_app_history_infos.append(MiniAppHistoryInfo.from_alipay_dict(i))

    def parse_response_content(self, response_content):
        response = super(AlipayOpenMiniMiniappHistoryQueryResponse, self).parse_response_content(response_content)
        if 'mini_app_history_infos' in response:
            self.mini_app_history_infos = response['mini_app_history_infos']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.SettleExtraParams import SettleExtraParams


class ZhimaCreditPeZmgoSettleApplyModel(object):

    def __init__(self):
        self._action_type = None
        self._agreement_id = None
        self._alipay_open_id = None
        self._alipay_user_id = None
        self._out_request_no = None
        self._partner_id = None
        self._pay_amount = None
        self._settle_extend_params = None
        self._total_discount_amount = None
        self._total_real_pay_amount = None
        self._total_task_count = None
        self._withhold_plan_no = None

    @property
    def action_type(self):
        return self._action_type

    @action_type.setter
    def action_type(self, value):
        self._action_type = value
    @property
    def agreement_id(self):
        return self._agreement_id

    @agreement_id.setter
    def agreement_id(self, value):
        self._agreement_id = value
    @property
    def alipay_open_id(self):
        return self._alipay_open_id

    @alipay_open_id.setter
    def alipay_open_id(self, value):
        self._alipay_open_id = value
    @property
    def alipay_user_id(self):
        return self._alipay_user_id

    @alipay_user_id.setter
    def alipay_user_id(self, value):
        self._alipay_user_id = value
    @property
    def out_request_no(self):
        return self._out_request_no

    @out_request_no.setter
    def out_request_no(self, value):
        self._out_request_no = value
    @property
    def partner_id(self):
        return self._partner_id

    @partner_id.setter
    def partner_id(self, value):
        self._partner_id = value
    @property
    def pay_amount(self):
        return self._pay_amount

    @pay_amount.setter
    def pay_amount(self, value):
        self._pay_amount = value
    @property
    def settle_extend_params(self):
        return self._settle_extend_params

    @settle_extend_params.setter
    def settle_extend_params(self, value):
        if isinstance(value, SettleExtraParams):
            self._settle_extend_params = value
        else:
            self._settle_extend_params = SettleExtraParams.from_alipay_dict(value)
    @property
    def total_discount_amount(self):
        return self._total_discount_amount

    @total_discount_amount.setter
    def total_discount_amount(self, value):
        self._total_discount_amount = value
    @property
    def total_real_pay_amount(self):
        return self._total_real_pay_amount

    @total_real_pay_amount.setter
    def total_real_pay_amount(self, value):
        self._total_real_pay_amount = value
    @property
    def total_task_count(self):
        return self._total_task_count

    @total_task_count.setter
    def total_task_count(self, value):
        self._total_task_count = value
    @property
    def withhold_plan_no(self):
        return self._withhold_plan_no

    @withhold_plan_no.setter
    def withhold_plan_no(self, value):
        self._withhold_plan_no = value


    def to_alipay_dict(self):
        params = dict()
        if self.action_type:
            if hasattr(self.action_type, 'to_alipay_dict'):
                params['action_type'] = self.action_type.to_alipay_dict()
            else:
                params['action_type'] = self.action_type
        if self.agreement_id:
            if hasattr(self.agreement_id, 'to_alipay_dict'):
                params['agreement_id'] = self.agreement_id.to_alipay_dict()
            else:
                params['agreement_id'] = self.agreement_id
        if self.alipay_open_id:
            if hasattr(self.alipay_open_id, 'to_alipay_dict'):
                params['alipay_open_id'] = self.alipay_open_id.to_alipay_dict()
            else:
                params['alipay_open_id'] = self.alipay_open_id
        if self.alipay_user_id:
            if hasattr(self.alipay_user_id, 'to_alipay_dict'):
                params['alipay_user_id'] = self.alipay_user_id.to_alipay_dict()
            else:
                params['alipay_user_id'] = self.alipay_user_id
        if self.out_request_no:
            if hasattr(self.out_request_no, 'to_alipay_dict'):
                params['out_request_no'] = self.out_request_no.to_alipay_dict()
            else:
                params['out_request_no'] = self.out_request_no
        if self.partner_id:
            if hasattr(self.partner_id, 'to_alipay_dict'):
                params['partner_id'] = self.partner_id.to_alipay_dict()
            else:
                params['partner_id'] = self.partner_id
        if self.pay_amount:
            if hasattr(self.pay_amount, 'to_alipay_dict'):
                params['pay_amount'] = self.pay_amount.to_alipay_dict()
            else:
                params['pay_amount'] = self.pay_amount
        if self.settle_extend_params:
            if hasattr(self.settle_extend_params, 'to_alipay_dict'):
                params['settle_extend_params'] = self.settle_extend_params.to_alipay_dict()
            else:
                params['settle_extend_params'] = self.settle_extend_params
        if self.total_discount_amount:
            if hasattr(self.total_discount_amount, 'to_alipay_dict'):
                params['total_discount_amount'] = self.total_discount_amount.to_alipay_dict()
            else:
                params['total_discount_amount'] = self.total_discount_amount
        if self.total_real_pay_amount:
            if hasattr(self.total_real_pay_amount, 'to_alipay_dict'):
                params['total_real_pay_amount'] = self.total_real_pay_amount.to_alipay_dict()
            else:
                params['total_real_pay_amount'] = self.total_real_pay_amount
        if self.total_task_count:
            if hasattr(self.total_task_count, 'to_alipay_dict'):
                params['total_task_count'] = self.total_task_count.to_alipay_dict()
            else:
                params['total_task_count'] = self.total_task_count
        if self.withhold_plan_no:
            if hasattr(self.withhold_plan_no, 'to_alipay_dict'):
                params['withhold_plan_no'] = self.withhold_plan_no.to_alipay_dict()
            else:
                params['withhold_plan_no'] = self.withhold_plan_no
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = ZhimaCreditPeZmgoSettleApplyModel()
        if 'action_type' in d:
            o.action_type = d['action_type']
        if 'agreement_id' in d:
            o.agreement_id = d['agreement_id']
        if 'alipay_open_id' in d:
            o.alipay_open_id = d['alipay_open_id']
        if 'alipay_user_id' in d:
            o.alipay_user_id = d['alipay_user_id']
        if 'out_request_no' in d:
            o.out_request_no = d['out_request_no']
        if 'partner_id' in d:
            o.partner_id = d['partner_id']
        if 'pay_amount' in d:
            o.pay_amount = d['pay_amount']
        if 'settle_extend_params' in d:
            o.settle_extend_params = d['settle_extend_params']
        if 'total_discount_amount' in d:
            o.total_discount_amount = d['total_discount_amount']
        if 'total_real_pay_amount' in d:
            o.total_real_pay_amount = d['total_real_pay_amount']
        if 'total_task_count' in d:
            o.total_task_count = d['total_task_count']
        if 'withhold_plan_no' in d:
            o.withhold_plan_no = d['withhold_plan_no']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class RefundPaymentAssetInfo(object):

    def __init__(self):
        self._bank_inst_id = None
        self._origin_order_id = None
        self._receiver_asset_code = None
        self._receiver_asset_no = None
        self._receiver_logon_id = None
        self._refund_amount = None

    @property
    def bank_inst_id(self):
        return self._bank_inst_id

    @bank_inst_id.setter
    def bank_inst_id(self, value):
        self._bank_inst_id = value
    @property
    def origin_order_id(self):
        return self._origin_order_id

    @origin_order_id.setter
    def origin_order_id(self, value):
        self._origin_order_id = value
    @property
    def receiver_asset_code(self):
        return self._receiver_asset_code

    @receiver_asset_code.setter
    def receiver_asset_code(self, value):
        self._receiver_asset_code = value
    @property
    def receiver_asset_no(self):
        return self._receiver_asset_no

    @receiver_asset_no.setter
    def receiver_asset_no(self, value):
        self._receiver_asset_no = value
    @property
    def receiver_logon_id(self):
        return self._receiver_logon_id

    @receiver_logon_id.setter
    def receiver_logon_id(self, value):
        self._receiver_logon_id = value
    @property
    def refund_amount(self):
        return self._refund_amount

    @refund_amount.setter
    def refund_amount(self, value):
        self._refund_amount = value


    def to_alipay_dict(self):
        params = dict()
        if self.bank_inst_id:
            if hasattr(self.bank_inst_id, 'to_alipay_dict'):
                params['bank_inst_id'] = self.bank_inst_id.to_alipay_dict()
            else:
                params['bank_inst_id'] = self.bank_inst_id
        if self.origin_order_id:
            if hasattr(self.origin_order_id, 'to_alipay_dict'):
                params['origin_order_id'] = self.origin_order_id.to_alipay_dict()
            else:
                params['origin_order_id'] = self.origin_order_id
        if self.receiver_asset_code:
            if hasattr(self.receiver_asset_code, 'to_alipay_dict'):
                params['receiver_asset_code'] = self.receiver_asset_code.to_alipay_dict()
            else:
                params['receiver_asset_code'] = self.receiver_asset_code
        if self.receiver_asset_no:
            if hasattr(self.receiver_asset_no, 'to_alipay_dict'):
                params['receiver_asset_no'] = self.receiver_asset_no.to_alipay_dict()
            else:
                params['receiver_asset_no'] = self.receiver_asset_no
        if self.receiver_logon_id:
            if hasattr(self.receiver_logon_id, 'to_alipay_dict'):
                params['receiver_logon_id'] = self.receiver_logon_id.to_alipay_dict()
            else:
                params['receiver_logon_id'] = self.receiver_logon_id
        if self.refund_amount:
            if hasattr(self.refund_amount, 'to_alipay_dict'):
                params['refund_amount'] = self.refund_amount.to_alipay_dict()
            else:
                params['refund_amount'] = self.refund_amount
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = RefundPaymentAssetInfo()
        if 'bank_inst_id' in d:
            o.bank_inst_id = d['bank_inst_id']
        if 'origin_order_id' in d:
            o.origin_order_id = d['origin_order_id']
        if 'receiver_asset_code' in d:
            o.receiver_asset_code = d['receiver_asset_code']
        if 'receiver_asset_no' in d:
            o.receiver_asset_no = d['receiver_asset_no']
        if 'receiver_logon_id' in d:
            o.receiver_logon_id = d['receiver_logon_id']
        if 'refund_amount' in d:
            o.refund_amount = d['refund_amount']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class PriceDetailDTO(object):

    def __init__(self):
        self._price_click_url = None
        self._price_title = None

    @property
    def price_click_url(self):
        return self._price_click_url

    @price_click_url.setter
    def price_click_url(self, value):
        self._price_click_url = value
    @property
    def price_title(self):
        return self._price_title

    @price_title.setter
    def price_title(self, value):
        self._price_title = value


    def to_alipay_dict(self):
        params = dict()
        if self.price_click_url:
            if hasattr(self.price_click_url, 'to_alipay_dict'):
                params['price_click_url'] = self.price_click_url.to_alipay_dict()
            else:
                params['price_click_url'] = self.price_click_url
        if self.price_title:
            if hasattr(self.price_title, 'to_alipay_dict'):
                params['price_title'] = self.price_title.to_alipay_dict()
            else:
                params['price_title'] = self.price_title
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = PriceDetailDTO()
        if 'price_click_url' in d:
            o.price_click_url = d['price_click_url']
        if 'price_title' in d:
            o.price_title = d['price_title']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayFinancialnetAuthEcsignDataprepareCreateModel(object):

    def __init__(self):
        self._back_type = None
        self._back_url = None
        self._ext_info = None
        self._jump_type = None
        self._out_order_no = None
        self._partner_id = None
        self._sign_product_id = None
        self._solution_code = None
        self._third_part_schema = None

    @property
    def back_type(self):
        return self._back_type

    @back_type.setter
    def back_type(self, value):
        self._back_type = value
    @property
    def back_url(self):
        return self._back_url

    @back_url.setter
    def back_url(self, value):
        self._back_url = value
    @property
    def ext_info(self):
        return self._ext_info

    @ext_info.setter
    def ext_info(self, value):
        self._ext_info = value
    @property
    def jump_type(self):
        return self._jump_type

    @jump_type.setter
    def jump_type(self, value):
        self._jump_type = value
    @property
    def out_order_no(self):
        return self._out_order_no

    @out_order_no.setter
    def out_order_no(self, value):
        self._out_order_no = value
    @property
    def partner_id(self):
        return self._partner_id

    @partner_id.setter
    def partner_id(self, value):
        self._partner_id = value
    @property
    def sign_product_id(self):
        return self._sign_product_id

    @sign_product_id.setter
    def sign_product_id(self, value):
        self._sign_product_id = value
    @property
    def solution_code(self):
        return self._solution_code

    @solution_code.setter
    def solution_code(self, value):
        self._solution_code = value
    @property
    def third_part_schema(self):
        return self._third_part_schema

    @third_part_schema.setter
    def third_part_schema(self, value):
        self._third_part_schema = value


    def to_alipay_dict(self):
        params = dict()
        if self.back_type:
            if hasattr(self.back_type, 'to_alipay_dict'):
                params['back_type'] = self.back_type.to_alipay_dict()
            else:
                params['back_type'] = self.back_type
        if self.back_url:
            if hasattr(self.back_url, 'to_alipay_dict'):
                params['back_url'] = self.back_url.to_alipay_dict()
            else:
                params['back_url'] = self.back_url
        if self.ext_info:
            if hasattr(self.ext_info, 'to_alipay_dict'):
                params['ext_info'] = self.ext_info.to_alipay_dict()
            else:
                params['ext_info'] = self.ext_info
        if self.jump_type:
            if hasattr(self.jump_type, 'to_alipay_dict'):
                params['jump_type'] = self.jump_type.to_alipay_dict()
            else:
                params['jump_type'] = self.jump_type
        if self.out_order_no:
            if hasattr(self.out_order_no, 'to_alipay_dict'):
                params['out_order_no'] = self.out_order_no.to_alipay_dict()
            else:
                params['out_order_no'] = self.out_order_no
        if self.partner_id:
            if hasattr(self.partner_id, 'to_alipay_dict'):
                params['partner_id'] = self.partner_id.to_alipay_dict()
            else:
                params['partner_id'] = self.partner_id
        if self.sign_product_id:
            if hasattr(self.sign_product_id, 'to_alipay_dict'):
                params['sign_product_id'] = self.sign_product_id.to_alipay_dict()
            else:
                params['sign_product_id'] = self.sign_product_id
        if self.solution_code:
            if hasattr(self.solution_code, 'to_alipay_dict'):
                params['solution_code'] = self.solution_code.to_alipay_dict()
            else:
                params['solution_code'] = self.solution_code
        if self.third_part_schema:
            if hasattr(self.third_part_schema, 'to_alipay_dict'):
                params['third_part_schema'] = self.third_part_schema.to_alipay_dict()
            else:
                params['third_part_schema'] = self.third_part_schema
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayFinancialnetAuthEcsignDataprepareCreateModel()
        if 'back_type' in d:
            o.back_type = d['back_type']
        if 'back_url' in d:
            o.back_url = d['back_url']
        if 'ext_info' in d:
            o.ext_info = d['ext_info']
        if 'jump_type' in d:
            o.jump_type = d['jump_type']
        if 'out_order_no' in d:
            o.out_order_no = d['out_order_no']
        if 'partner_id' in d:
            o.partner_id = d['partner_id']
        if 'sign_product_id' in d:
            o.sign_product_id = d['sign_product_id']
        if 'solution_code' in d:
            o.solution_code = d['solution_code']
        if 'third_part_schema' in d:
            o.third_part_schema = d['third_part_schema']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayOverseasRemitBeneficialinfoQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayOverseasRemitBeneficialinfoQueryResponse, self).__init__()
        self._bank_account = None
        self._bank_english_name = None
        self._bank_inst_id = None
        self._bank_name = None
        self._extend_info = None
        self._has_sync_result = None

    @property
    def bank_account(self):
        return self._bank_account

    @bank_account.setter
    def bank_account(self, value):
        self._bank_account = value
    @property
    def bank_english_name(self):
        return self._bank_english_name

    @bank_english_name.setter
    def bank_english_name(self, value):
        self._bank_english_name = value
    @property
    def bank_inst_id(self):
        return self._bank_inst_id

    @bank_inst_id.setter
    def bank_inst_id(self, value):
        self._bank_inst_id = value
    @property
    def bank_name(self):
        return self._bank_name

    @bank_name.setter
    def bank_name(self, value):
        self._bank_name = value
    @property
    def extend_info(self):
        return self._extend_info

    @extend_info.setter
    def extend_info(self, value):
        self._extend_info = value
    @property
    def has_sync_result(self):
        return self._has_sync_result

    @has_sync_result.setter
    def has_sync_result(self, value):
        self._has_sync_result = value

    def parse_response_content(self, response_content):
        response = super(AlipayOverseasRemitBeneficialinfoQueryResponse, self).parse_response_content(response_content)
        if 'bank_account' in response:
            self.bank_account = response['bank_account']
        if 'bank_english_name' in response:
            self.bank_english_name = response['bank_english_name']
        if 'bank_inst_id' in response:
            self.bank_inst_id = response['bank_inst_id']
        if 'bank_name' in response:
            self.bank_name = response['bank_name']
        if 'extend_info' in response:
            self.extend_info = response['extend_info']
        if 'has_sync_result' in response:
            self.has_sync_result = response['has_sync_result']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayCommerceIotMdeviceprodDeviceInitializeModel(object):

    def __init__(self):
        self._device_sn = None
        self._ext_info = None
        self._imei = None
        self._item_id = None
        self._mac = None
        self._net_type = None
        self._os_version = None
        self._plain_text = None
        self._sign_info = None
        self._supplier_id = None

    @property
    def device_sn(self):
        return self._device_sn

    @device_sn.setter
    def device_sn(self, value):
        self._device_sn = value
    @property
    def ext_info(self):
        return self._ext_info

    @ext_info.setter
    def ext_info(self, value):
        self._ext_info = value
    @property
    def imei(self):
        return self._imei

    @imei.setter
    def imei(self, value):
        self._imei = value
    @property
    def item_id(self):
        return self._item_id

    @item_id.setter
    def item_id(self, value):
        self._item_id = value
    @property
    def mac(self):
        return self._mac

    @mac.setter
    def mac(self, value):
        self._mac = value
    @property
    def net_type(self):
        return self._net_type

    @net_type.setter
    def net_type(self, value):
        self._net_type = value
    @property
    def os_version(self):
        return self._os_version

    @os_version.setter
    def os_version(self, value):
        self._os_version = value
    @property
    def plain_text(self):
        return self._plain_text

    @plain_text.setter
    def plain_text(self, value):
        self._plain_text = value
    @property
    def sign_info(self):
        return self._sign_info

    @sign_info.setter
    def sign_info(self, value):
        self._sign_info = value
    @property
    def supplier_id(self):
        return self._supplier_id

    @supplier_id.setter
    def supplier_id(self, value):
        self._supplier_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.device_sn:
            if hasattr(self.device_sn, 'to_alipay_dict'):
                params['device_sn'] = self.device_sn.to_alipay_dict()
            else:
                params['device_sn'] = self.device_sn
        if self.ext_info:
            if hasattr(self.ext_info, 'to_alipay_dict'):
                params['ext_info'] = self.ext_info.to_alipay_dict()
            else:
                params['ext_info'] = self.ext_info
        if self.imei:
            if hasattr(self.imei, 'to_alipay_dict'):
                params['imei'] = self.imei.to_alipay_dict()
            else:
                params['imei'] = self.imei
        if self.item_id:
            if hasattr(self.item_id, 'to_alipay_dict'):
                params['item_id'] = self.item_id.to_alipay_dict()
            else:
                params['item_id'] = self.item_id
        if self.mac:
            if hasattr(self.mac, 'to_alipay_dict'):
                params['mac'] = self.mac.to_alipay_dict()
            else:
                params['mac'] = self.mac
        if self.net_type:
            if hasattr(self.net_type, 'to_alipay_dict'):
                params['net_type'] = self.net_type.to_alipay_dict()
            else:
                params['net_type'] = self.net_type
        if self.os_version:
            if hasattr(self.os_version, 'to_alipay_dict'):
                params['os_version'] = self.os_version.to_alipay_dict()
            else:
                params['os_version'] = self.os_version
        if self.plain_text:
            if hasattr(self.plain_text, 'to_alipay_dict'):
                params['plain_text'] = self.plain_text.to_alipay_dict()
            else:
                params['plain_text'] = self.plain_text
        if self.sign_info:
            if hasattr(self.sign_info, 'to_alipay_dict'):
                params['sign_info'] = self.sign_info.to_alipay_dict()
            else:
                params['sign_info'] = self.sign_info
        if self.supplier_id:
            if hasattr(self.supplier_id, 'to_alipay_dict'):
                params['supplier_id'] = self.supplier_id.to_alipay_dict()
            else:
                params['supplier_id'] = self.supplier_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayCommerceIotMdeviceprodDeviceInitializeModel()
        if 'device_sn' in d:
            o.device_sn = d['device_sn']
        if 'ext_info' in d:
            o.ext_info = d['ext_info']
        if 'imei' in d:
            o.imei = d['imei']
        if 'item_id' in d:
            o.item_id = d['item_id']
        if 'mac' in d:
            o.mac = d['mac']
        if 'net_type' in d:
            o.net_type = d['net_type']
        if 'os_version' in d:
            o.os_version = d['os_version']
        if 'plain_text' in d:
            o.plain_text = d['plain_text']
        if 'sign_info' in d:
            o.sign_info = d['sign_info']
        if 'supplier_id' in d:
            o.supplier_id = d['supplier_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.DashboardParam import DashboardParam


class AlipayMarketingDataDashboardQueryModel(object):

    def __init__(self):
        self._dashboard_id = None
        self._param = None

    @property
    def dashboard_id(self):
        return self._dashboard_id

    @dashboard_id.setter
    def dashboard_id(self, value):
        self._dashboard_id = value
    @property
    def param(self):
        return self._param

    @param.setter
    def param(self, value):
        if isinstance(value, list):
            self._param = list()
            for i in value:
                if isinstance(i, DashboardParam):
                    self._param.append(i)
                else:
                    self._param.append(DashboardParam.from_alipay_dict(i))


    def to_alipay_dict(self):
        params = dict()
        if self.dashboard_id:
            if hasattr(self.dashboard_id, 'to_alipay_dict'):
                params['dashboard_id'] = self.dashboard_id.to_alipay_dict()
            else:
                params['dashboard_id'] = self.dashboard_id
        if self.param:
            if isinstance(self.param, list):
                for i in range(0, len(self.param)):
                    element = self.param[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.param[i] = element.to_alipay_dict()
            if hasattr(self.param, 'to_alipay_dict'):
                params['param'] = self.param.to_alipay_dict()
            else:
                params['param'] = self.param
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayMarketingDataDashboardQueryModel()
        if 'dashboard_id' in d:
            o.dashboard_id = d['dashboard_id']
        if 'param' in d:
            o.param = d['param']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.BillDetailVo import BillDetailVo
from alipay.aop.api.domain.RefuseVo import RefuseVo


class MybankCreditLoantradeBillListQueryResponse(AlipayResponse):

    def __init__(self):
        super(MybankCreditLoantradeBillListQueryResponse, self).__init__()
        self._bill_detail_list = None
        self._has_next_page = None
        self._page_num = None
        self._page_size = None
        self._refuse_msg = None
        self._success = None

    @property
    def bill_detail_list(self):
        return self._bill_detail_list

    @bill_detail_list.setter
    def bill_detail_list(self, value):
        if isinstance(value, BillDetailVo):
            self._bill_detail_list = value
        else:
            self._bill_detail_list = BillDetailVo.from_alipay_dict(value)
    @property
    def has_next_page(self):
        return self._has_next_page

    @has_next_page.setter
    def has_next_page(self, value):
        self._has_next_page = value
    @property
    def page_num(self):
        return self._page_num

    @page_num.setter
    def page_num(self, value):
        self._page_num = value
    @property
    def page_size(self):
        return self._page_size

    @page_size.setter
    def page_size(self, value):
        self._page_size = value
    @property
    def refuse_msg(self):
        return self._refuse_msg

    @refuse_msg.setter
    def refuse_msg(self, value):
        if isinstance(value, RefuseVo):
            self._refuse_msg = value
        else:
            self._refuse_msg = RefuseVo.from_alipay_dict(value)
    @property
    def success(self):
        return self._success

    @success.setter
    def success(self, value):
        self._success = value

    def parse_response_content(self, response_content):
        response = super(MybankCreditLoantradeBillListQueryResponse, self).parse_response_content(response_content)
        if 'bill_detail_list' in response:
            self.bill_detail_list = response['bill_detail_list']
        if 'has_next_page' in response:
            self.has_next_page = response['has_next_page']
        if 'page_num' in response:
            self.page_num = response['page_num']
        if 'page_size' in response:
            self.page_size = response['page_size']
        if 'refuse_msg' in response:
            self.refuse_msg = response['refuse_msg']
        if 'success' in response:
            self.success = response['success']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayEbppInvoiceExpensecontrolQuotaCreateModel(object):

    def __init__(self):
        self._account_id = None
        self._agreement_no = None
        self._effective_end_date = None
        self._effective_start_date = None
        self._enterprise_id = None
        self._outer_source_id = None
        self._owner_id = None
        self._owner_open_id = None
        self._owner_type = None
        self._platform = None
        self._quota_type = None
        self._quota_value = None
        self._share_mode = None
        self._target_id = None
        self._target_type = None

    @property
    def account_id(self):
        return self._account_id

    @account_id.setter
    def account_id(self, value):
        self._account_id = value
    @property
    def agreement_no(self):
        return self._agreement_no

    @agreement_no.setter
    def agreement_no(self, value):
        self._agreement_no = value
    @property
    def effective_end_date(self):
        return self._effective_end_date

    @effective_end_date.setter
    def effective_end_date(self, value):
        self._effective_end_date = value
    @property
    def effective_start_date(self):
        return self._effective_start_date

    @effective_start_date.setter
    def effective_start_date(self, value):
        self._effective_start_date = value
    @property
    def enterprise_id(self):
        return self._enterprise_id

    @enterprise_id.setter
    def enterprise_id(self, value):
        self._enterprise_id = value
    @property
    def outer_source_id(self):
        return self._outer_source_id

    @outer_source_id.setter
    def outer_source_id(self, value):
        self._outer_source_id = value
    @property
    def owner_id(self):
        return self._owner_id

    @owner_id.setter
    def owner_id(self, value):
        self._owner_id = value
    @property
    def owner_open_id(self):
        return self._owner_open_id

    @owner_open_id.setter
    def owner_open_id(self, value):
        self._owner_open_id = value
    @property
    def owner_type(self):
        return self._owner_type

    @owner_type.setter
    def owner_type(self, value):
        self._owner_type = value
    @property
    def platform(self):
        return self._platform

    @platform.setter
    def platform(self, value):
        self._platform = value
    @property
    def quota_type(self):
        return self._quota_type

    @quota_type.setter
    def quota_type(self, value):
        self._quota_type = value
    @property
    def quota_value(self):
        return self._quota_value

    @quota_value.setter
    def quota_value(self, value):
        self._quota_value = value
    @property
    def share_mode(self):
        return self._share_mode

    @share_mode.setter
    def share_mode(self, value):
        self._share_mode = value
    @property
    def target_id(self):
        return self._target_id

    @target_id.setter
    def target_id(self, value):
        self._target_id = value
    @property
    def target_type(self):
        return self._target_type

    @target_type.setter
    def target_type(self, value):
        self._target_type = value


    def to_alipay_dict(self):
        params = dict()
        if self.account_id:
            if hasattr(self.account_id, 'to_alipay_dict'):
                params['account_id'] = self.account_id.to_alipay_dict()
            else:
                params['account_id'] = self.account_id
        if self.agreement_no:
            if hasattr(self.agreement_no, 'to_alipay_dict'):
                params['agreement_no'] = self.agreement_no.to_alipay_dict()
            else:
                params['agreement_no'] = self.agreement_no
        if self.effective_end_date:
            if hasattr(self.effective_end_date, 'to_alipay_dict'):
                params['effective_end_date'] = self.effective_end_date.to_alipay_dict()
            else:
                params['effective_end_date'] = self.effective_end_date
        if self.effective_start_date:
            if hasattr(self.effective_start_date, 'to_alipay_dict'):
                params['effective_start_date'] = self.effective_start_date.to_alipay_dict()
            else:
                params['effective_start_date'] = self.effective_start_date
        if self.enterprise_id:
            if hasattr(self.enterprise_id, 'to_alipay_dict'):
                params['enterprise_id'] = self.enterprise_id.to_alipay_dict()
            else:
                params['enterprise_id'] = self.enterprise_id
        if self.outer_source_id:
            if hasattr(self.outer_source_id, 'to_alipay_dict'):
                params['outer_source_id'] = self.outer_source_id.to_alipay_dict()
            else:
                params['outer_source_id'] = self.outer_source_id
        if self.owner_id:
            if hasattr(self.owner_id, 'to_alipay_dict'):
                params['owner_id'] = self.owner_id.to_alipay_dict()
            else:
                params['owner_id'] = self.owner_id
        if self.owner_open_id:
            if hasattr(self.owner_open_id, 'to_alipay_dict'):
                params['owner_open_id'] = self.owner_open_id.to_alipay_dict()
            else:
                params['owner_open_id'] = self.owner_open_id
        if self.owner_type:
            if hasattr(self.owner_type, 'to_alipay_dict'):
                params['owner_type'] = self.owner_type.to_alipay_dict()
            else:
                params['owner_type'] = self.owner_type
        if self.platform:
            if hasattr(self.platform, 'to_alipay_dict'):
                params['platform'] = self.platform.to_alipay_dict()
            else:
                params['platform'] = self.platform
        if self.quota_type:
            if hasattr(self.quota_type, 'to_alipay_dict'):
                params['quota_type'] = self.quota_type.to_alipay_dict()
            else:
                params['quota_type'] = self.quota_type
        if self.quota_value:
            if hasattr(self.quota_value, 'to_alipay_dict'):
                params['quota_value'] = self.quota_value.to_alipay_dict()
            else:
                params['quota_value'] = self.quota_value
        if self.share_mode:
            if hasattr(self.share_mode, 'to_alipay_dict'):
                params['share_mode'] = self.share_mode.to_alipay_dict()
            else:
                params['share_mode'] = self.share_mode
        if self.target_id:
            if hasattr(self.target_id, 'to_alipay_dict'):
                params['target_id'] = self.target_id.to_alipay_dict()
            else:
                params['target_id'] = self.target_id
        if self.target_type:
            if hasattr(self.target_type, 'to_alipay_dict'):
                params['target_type'] = self.target_type.to_alipay_dict()
            else:
                params['target_type'] = self.target_type
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayEbppInvoiceExpensecontrolQuotaCreateModel()
        if 'account_id' in d:
            o.account_id = d['account_id']
        if 'agreement_no' in d:
            o.agreement_no = d['agreement_no']
        if 'effective_end_date' in d:
            o.effective_end_date = d['effective_end_date']
        if 'effective_start_date' in d:
            o.effective_start_date = d['effective_start_date']
        if 'enterprise_id' in d:
            o.enterprise_id = d['enterprise_id']
        if 'outer_source_id' in d:
            o.outer_source_id = d['outer_source_id']
        if 'owner_id' in d:
            o.owner_id = d['owner_id']
        if 'owner_open_id' in d:
            o.owner_open_id = d['owner_open_id']
        if 'owner_type' in d:
            o.owner_type = d['owner_type']
        if 'platform' in d:
            o.platform = d['platform']
        if 'quota_type' in d:
            o.quota_type = d['quota_type']
        if 'quota_value' in d:
            o.quota_value = d['quota_value']
        if 'share_mode' in d:
            o.share_mode = d['share_mode']
        if 'target_id' in d:
            o.target_id = d['target_id']
        if 'target_type' in d:
            o.target_type = d['target_type']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.AccessCheckInfo import AccessCheckInfo
from alipay.aop.api.domain.BrandCertInfo import BrandCertInfo
from alipay.aop.api.domain.SearchBoxAppInfo import SearchBoxAppInfo


class AlipayOpenSearchboxDowngradePreconsultResponse(AlipayResponse):

    def __init__(self):
        super(AlipayOpenSearchboxDowngradePreconsultResponse, self).__init__()
        self._access_check_info = None
        self._applicable_box_type = None
        self._brand_cert_info = None
        self._opt_principal_id = None
        self._tiny_app_info = None

    @property
    def access_check_info(self):
        return self._access_check_info

    @access_check_info.setter
    def access_check_info(self, value):
        if isinstance(value, AccessCheckInfo):
            self._access_check_info = value
        else:
            self._access_check_info = AccessCheckInfo.from_alipay_dict(value)
    @property
    def applicable_box_type(self):
        return self._applicable_box_type

    @applicable_box_type.setter
    def applicable_box_type(self, value):
        self._applicable_box_type = value
    @property
    def brand_cert_info(self):
        return self._brand_cert_info

    @brand_cert_info.setter
    def brand_cert_info(self, value):
        if isinstance(value, BrandCertInfo):
            self._brand_cert_info = value
        else:
            self._brand_cert_info = BrandCertInfo.from_alipay_dict(value)
    @property
    def opt_principal_id(self):
        return self._opt_principal_id

    @opt_principal_id.setter
    def opt_principal_id(self, value):
        self._opt_principal_id = value
    @property
    def tiny_app_info(self):
        return self._tiny_app_info

    @tiny_app_info.setter
    def tiny_app_info(self, value):
        if isinstance(value, SearchBoxAppInfo):
            self._tiny_app_info = value
        else:
            self._tiny_app_info = SearchBoxAppInfo.from_alipay_dict(value)

    def parse_response_content(self, response_content):
        response = super(AlipayOpenSearchboxDowngradePreconsultResponse, self).parse_response_content(response_content)
        if 'access_check_info' in response:
            self.access_check_info = response['access_check_info']
        if 'applicable_box_type' in response:
            self.applicable_box_type = response['applicable_box_type']
        if 'brand_cert_info' in response:
            self.brand_cert_info = response['brand_cert_info']
        if 'opt_principal_id' in response:
            self.opt_principal_id = response['opt_principal_id']
        if 'tiny_app_info' in response:
            self.tiny_app_info = response['tiny_app_info']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class JobworthAdapter(object):

    def __init__(self):
        self._age = None
        self._city = None
        self._edu_level = None
        self._gender = None
        self._recommend = None
        self._skill_certificate = None

    @property
    def age(self):
        return self._age

    @age.setter
    def age(self, value):
        self._age = value
    @property
    def city(self):
        return self._city

    @city.setter
    def city(self, value):
        self._city = value
    @property
    def edu_level(self):
        return self._edu_level

    @edu_level.setter
    def edu_level(self, value):
        self._edu_level = value
    @property
    def gender(self):
        return self._gender

    @gender.setter
    def gender(self, value):
        self._gender = value
    @property
    def recommend(self):
        return self._recommend

    @recommend.setter
    def recommend(self, value):
        self._recommend = value
    @property
    def skill_certificate(self):
        return self._skill_certificate

    @skill_certificate.setter
    def skill_certificate(self, value):
        self._skill_certificate = value


    def to_alipay_dict(self):
        params = dict()
        if self.age:
            if hasattr(self.age, 'to_alipay_dict'):
                params['age'] = self.age.to_alipay_dict()
            else:
                params['age'] = self.age
        if self.city:
            if hasattr(self.city, 'to_alipay_dict'):
                params['city'] = self.city.to_alipay_dict()
            else:
                params['city'] = self.city
        if self.edu_level:
            if hasattr(self.edu_level, 'to_alipay_dict'):
                params['edu_level'] = self.edu_level.to_alipay_dict()
            else:
                params['edu_level'] = self.edu_level
        if self.gender:
            if hasattr(self.gender, 'to_alipay_dict'):
                params['gender'] = self.gender.to_alipay_dict()
            else:
                params['gender'] = self.gender
        if self.recommend:
            if hasattr(self.recommend, 'to_alipay_dict'):
                params['recommend'] = self.recommend.to_alipay_dict()
            else:
                params['recommend'] = self.recommend
        if self.skill_certificate:
            if hasattr(self.skill_certificate, 'to_alipay_dict'):
                params['skill_certificate'] = self.skill_certificate.to_alipay_dict()
            else:
                params['skill_certificate'] = self.skill_certificate
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = JobworthAdapter()
        if 'age' in d:
            o.age = d['age']
        if 'city' in d:
            o.city = d['city']
        if 'edu_level' in d:
            o.edu_level = d['edu_level']
        if 'gender' in d:
            o.gender = d['gender']
        if 'recommend' in d:
            o.recommend = d['recommend']
        if 'skill_certificate' in d:
            o.skill_certificate = d['skill_certificate']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayInsSceneApplicationOutsideApplyResponse(AlipayResponse):

    def __init__(self):
        super(AlipayInsSceneApplicationOutsideApplyResponse, self).__init__()
        self._out_biz_no = None
        self._policy_no = None
        self._premium = None
        self._risk_level = None
        self._sum_insured = None

    @property
    def out_biz_no(self):
        return self._out_biz_no

    @out_biz_no.setter
    def out_biz_no(self, value):
        self._out_biz_no = value
    @property
    def policy_no(self):
        return self._policy_no

    @policy_no.setter
    def policy_no(self, value):
        self._policy_no = value
    @property
    def premium(self):
        return self._premium

    @premium.setter
    def premium(self, value):
        self._premium = value
    @property
    def risk_level(self):
        return self._risk_level

    @risk_level.setter
    def risk_level(self, value):
        self._risk_level = value
    @property
    def sum_insured(self):
        return self._sum_insured

    @sum_insured.setter
    def sum_insured(self, value):
        self._sum_insured = value

    def parse_response_content(self, response_content):
        response = super(AlipayInsSceneApplicationOutsideApplyResponse, self).parse_response_content(response_content)
        if 'out_biz_no' in response:
            self.out_biz_no = response['out_biz_no']
        if 'policy_no' in response:
            self.policy_no = response['policy_no']
        if 'premium' in response:
            self.premium = response['premium']
        if 'risk_level' in response:
            self.risk_level = response['risk_level']
        if 'sum_insured' in response:
            self.sum_insured = response['sum_insured']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class MybankCreditLoanapplyDataQueryModel(object):

    def __init__(self):
        self._biz_no = None
        self._biz_type = None
        self._category = None
        self._data_version = None
        self._entity_code = None
        self._entity_name = None
        self._entity_type = None
        self._ip_id = None
        self._ip_role_id = None

    @property
    def biz_no(self):
        return self._biz_no

    @biz_no.setter
    def biz_no(self, value):
        self._biz_no = value
    @property
    def biz_type(self):
        return self._biz_type

    @biz_type.setter
    def biz_type(self, value):
        self._biz_type = value
    @property
    def category(self):
        return self._category

    @category.setter
    def category(self, value):
        self._category = value
    @property
    def data_version(self):
        return self._data_version

    @data_version.setter
    def data_version(self, value):
        self._data_version = value
    @property
    def entity_code(self):
        return self._entity_code

    @entity_code.setter
    def entity_code(self, value):
        self._entity_code = value
    @property
    def entity_name(self):
        return self._entity_name

    @entity_name.setter
    def entity_name(self, value):
        self._entity_name = value
    @property
    def entity_type(self):
        return self._entity_type

    @entity_type.setter
    def entity_type(self, value):
        self._entity_type = value
    @property
    def ip_id(self):
        return self._ip_id

    @ip_id.setter
    def ip_id(self, value):
        self._ip_id = value
    @property
    def ip_role_id(self):
        return self._ip_role_id

    @ip_role_id.setter
    def ip_role_id(self, value):
        self._ip_role_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.biz_no:
            if hasattr(self.biz_no, 'to_alipay_dict'):
                params['biz_no'] = self.biz_no.to_alipay_dict()
            else:
                params['biz_no'] = self.biz_no
        if self.biz_type:
            if hasattr(self.biz_type, 'to_alipay_dict'):
                params['biz_type'] = self.biz_type.to_alipay_dict()
            else:
                params['biz_type'] = self.biz_type
        if self.category:
            if hasattr(self.category, 'to_alipay_dict'):
                params['category'] = self.category.to_alipay_dict()
            else:
                params['category'] = self.category
        if self.data_version:
            if hasattr(self.data_version, 'to_alipay_dict'):
                params['data_version'] = self.data_version.to_alipay_dict()
            else:
                params['data_version'] = self.data_version
        if self.entity_code:
            if hasattr(self.entity_code, 'to_alipay_dict'):
                params['entity_code'] = self.entity_code.to_alipay_dict()
            else:
                params['entity_code'] = self.entity_code
        if self.entity_name:
            if hasattr(self.entity_name, 'to_alipay_dict'):
                params['entity_name'] = self.entity_name.to_alipay_dict()
            else:
                params['entity_name'] = self.entity_name
        if self.entity_type:
            if hasattr(self.entity_type, 'to_alipay_dict'):
                params['entity_type'] = self.entity_type.to_alipay_dict()
            else:
                params['entity_type'] = self.entity_type
        if self.ip_id:
            if hasattr(self.ip_id, 'to_alipay_dict'):
                params['ip_id'] = self.ip_id.to_alipay_dict()
            else:
                params['ip_id'] = self.ip_id
        if self.ip_role_id:
            if hasattr(self.ip_role_id, 'to_alipay_dict'):
                params['ip_role_id'] = self.ip_role_id.to_alipay_dict()
            else:
                params['ip_role_id'] = self.ip_role_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = MybankCreditLoanapplyDataQueryModel()
        if 'biz_no' in d:
            o.biz_no = d['biz_no']
        if 'biz_type' in d:
            o.biz_type = d['biz_type']
        if 'category' in d:
            o.category = d['category']
        if 'data_version' in d:
            o.data_version = d['data_version']
        if 'entity_code' in d:
            o.entity_code = d['entity_code']
        if 'entity_name' in d:
            o.entity_name = d['entity_name']
        if 'entity_type' in d:
            o.entity_type = d['entity_type']
        if 'ip_id' in d:
            o.ip_id = d['ip_id']
        if 'ip_role_id' in d:
            o.ip_role_id = d['ip_role_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.IsvSpiDefinition import IsvSpiDefinition


class AlipayIserviceCcmServiceInitializeModel(object):

    def __init__(self):
        self._description = None
        self._icon = None
        self._service_code = None
        self._service_name = None
        self._service_order_url = None
        self._spis = None

    @property
    def description(self):
        return self._description

    @description.setter
    def description(self, value):
        self._description = value
    @property
    def icon(self):
        return self._icon

    @icon.setter
    def icon(self, value):
        self._icon = value
    @property
    def service_code(self):
        return self._service_code

    @service_code.setter
    def service_code(self, value):
        self._service_code = value
    @property
    def service_name(self):
        return self._service_name

    @service_name.setter
    def service_name(self, value):
        self._service_name = value
    @property
    def service_order_url(self):
        return self._service_order_url

    @service_order_url.setter
    def service_order_url(self, value):
        self._service_order_url = value
    @property
    def spis(self):
        return self._spis

    @spis.setter
    def spis(self, value):
        if isinstance(value, list):
            self._spis = list()
            for i in value:
                if isinstance(i, IsvSpiDefinition):
                    self._spis.append(i)
                else:
                    self._spis.append(IsvSpiDefinition.from_alipay_dict(i))


    def to_alipay_dict(self):
        params = dict()
        if self.description:
            if hasattr(self.description, 'to_alipay_dict'):
                params['description'] = self.description.to_alipay_dict()
            else:
                params['description'] = self.description
        if self.icon:
            if hasattr(self.icon, 'to_alipay_dict'):
                params['icon'] = self.icon.to_alipay_dict()
            else:
                params['icon'] = self.icon
        if self.service_code:
            if hasattr(self.service_code, 'to_alipay_dict'):
                params['service_code'] = self.service_code.to_alipay_dict()
            else:
                params['service_code'] = self.service_code
        if self.service_name:
            if hasattr(self.service_name, 'to_alipay_dict'):
                params['service_name'] = self.service_name.to_alipay_dict()
            else:
                params['service_name'] = self.service_name
        if self.service_order_url:
            if hasattr(self.service_order_url, 'to_alipay_dict'):
                params['service_order_url'] = self.service_order_url.to_alipay_dict()
            else:
                params['service_order_url'] = self.service_order_url
        if self.spis:
            if isinstance(self.spis, list):
                for i in range(0, len(self.spis)):
                    element = self.spis[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.spis[i] = element.to_alipay_dict()
            if hasattr(self.spis, 'to_alipay_dict'):
                params['spis'] = self.spis.to_alipay_dict()
            else:
                params['spis'] = self.spis
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayIserviceCcmServiceInitializeModel()
        if 'description' in d:
            o.description = d['description']
        if 'icon' in d:
            o.icon = d['icon']
        if 'service_code' in d:
            o.service_code = d['service_code']
        if 'service_name' in d:
            o.service_name = d['service_name']
        if 'service_order_url' in d:
            o.service_order_url = d['service_order_url']
        if 'spis' in d:
            o.spis = d['spis']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayIserviceCcmRoleCreateResponse(AlipayResponse):

    def __init__(self):
        super(AlipayIserviceCcmRoleCreateResponse, self).__init__()
        self._id = None

    @property
    def id(self):
        return self._id

    @id.setter
    def id(self, value):
        self._id = value

    def parse_response_content(self, response_content):
        response = super(AlipayIserviceCcmRoleCreateResponse, self).parse_response_content(response_content)
        if 'id' in response:
            self.id = response['id']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayOpenMiniCloudAosbehaviorSyncModel(object):

    def __init__(self):
        self._action_type = None
        self._channel = None
        self._item_id_list = None
        self._item_num = None
        self._log_time = None
        self._open_id = None
        self._order_id = None
        self._page_stay = None
        self._pay_amount = None
        self._pos = None
        self._project_id = None
        self._query = None
        self._spm = None
        self._trace_id = None
        self._user_id = None
        self._user_id_type = None
        self._video_duration = None
        self._video_play = None

    @property
    def action_type(self):
        return self._action_type

    @action_type.setter
    def action_type(self, value):
        self._action_type = value
    @property
    def channel(self):
        return self._channel

    @channel.setter
    def channel(self, value):
        self._channel = value
    @property
    def item_id_list(self):
        return self._item_id_list

    @item_id_list.setter
    def item_id_list(self, value):
        self._item_id_list = value
    @property
    def item_num(self):
        return self._item_num

    @item_num.setter
    def item_num(self, value):
        self._item_num = value
    @property
    def log_time(self):
        return self._log_time

    @log_time.setter
    def log_time(self, value):
        self._log_time = value
    @property
    def open_id(self):
        return self._open_id

    @open_id.setter
    def open_id(self, value):
        self._open_id = value
    @property
    def order_id(self):
        return self._order_id

    @order_id.setter
    def order_id(self, value):
        self._order_id = value
    @property
    def page_stay(self):
        return self._page_stay

    @page_stay.setter
    def page_stay(self, value):
        self._page_stay = value
    @property
    def pay_amount(self):
        return self._pay_amount

    @pay_amount.setter
    def pay_amount(self, value):
        self._pay_amount = value
    @property
    def pos(self):
        return self._pos

    @pos.setter
    def pos(self, value):
        self._pos = value
    @property
    def project_id(self):
        return self._project_id

    @project_id.setter
    def project_id(self, value):
        self._project_id = value
    @property
    def query(self):
        return self._query

    @query.setter
    def query(self, value):
        self._query = value
    @property
    def spm(self):
        return self._spm

    @spm.setter
    def spm(self, value):
        self._spm = value
    @property
    def trace_id(self):
        return self._trace_id

    @trace_id.setter
    def trace_id(self, value):
        self._trace_id = value
    @property
    def user_id(self):
        return self._user_id

    @user_id.setter
    def user_id(self, value):
        self._user_id = value
    @property
    def user_id_type(self):
        return self._user_id_type

    @user_id_type.setter
    def user_id_type(self, value):
        self._user_id_type = value
    @property
    def video_duration(self):
        return self._video_duration

    @video_duration.setter
    def video_duration(self, value):
        self._video_duration = value
    @property
    def video_play(self):
        return self._video_play

    @video_play.setter
    def video_play(self, value):
        self._video_play = value


    def to_alipay_dict(self):
        params = dict()
        if self.action_type:
            if hasattr(self.action_type, 'to_alipay_dict'):
                params['action_type'] = self.action_type.to_alipay_dict()
            else:
                params['action_type'] = self.action_type
        if self.channel:
            if hasattr(self.channel, 'to_alipay_dict'):
                params['channel'] = self.channel.to_alipay_dict()
            else:
                params['channel'] = self.channel
        if self.item_id_list:
            if hasattr(self.item_id_list, 'to_alipay_dict'):
                params['item_id_list'] = self.item_id_list.to_alipay_dict()
            else:
                params['item_id_list'] = self.item_id_list
        if self.item_num:
            if hasattr(self.item_num, 'to_alipay_dict'):
                params['item_num'] = self.item_num.to_alipay_dict()
            else:
                params['item_num'] = self.item_num
        if self.log_time:
            if hasattr(self.log_time, 'to_alipay_dict'):
                params['log_time'] = self.log_time.to_alipay_dict()
            else:
                params['log_time'] = self.log_time
        if self.open_id:
            if hasattr(self.open_id, 'to_alipay_dict'):
                params['open_id'] = self.open_id.to_alipay_dict()
            else:
                params['open_id'] = self.open_id
        if self.order_id:
            if hasattr(self.order_id, 'to_alipay_dict'):
                params['order_id'] = self.order_id.to_alipay_dict()
            else:
                params['order_id'] = self.order_id
        if self.page_stay:
            if hasattr(self.page_stay, 'to_alipay_dict'):
                params['page_stay'] = self.page_stay.to_alipay_dict()
            else:
                params['page_stay'] = self.page_stay
        if self.pay_amount:
            if hasattr(self.pay_amount, 'to_alipay_dict'):
                params['pay_amount'] = self.pay_amount.to_alipay_dict()
            else:
                params['pay_amount'] = self.pay_amount
        if self.pos:
            if hasattr(self.pos, 'to_alipay_dict'):
                params['pos'] = self.pos.to_alipay_dict()
            else:
                params['pos'] = self.pos
        if self.project_id:
            if hasattr(self.project_id, 'to_alipay_dict'):
                params['project_id'] = self.project_id.to_alipay_dict()
            else:
                params['project_id'] = self.project_id
        if self.query:
            if hasattr(self.query, 'to_alipay_dict'):
                params['query'] = self.query.to_alipay_dict()
            else:
                params['query'] = self.query
        if self.spm:
            if hasattr(self.spm, 'to_alipay_dict'):
                params['spm'] = self.spm.to_alipay_dict()
            else:
                params['spm'] = self.spm
        if self.trace_id:
            if hasattr(self.trace_id, 'to_alipay_dict'):
                params['trace_id'] = self.trace_id.to_alipay_dict()
            else:
                params['trace_id'] = self.trace_id
        if self.user_id:
            if hasattr(self.user_id, 'to_alipay_dict'):
                params['user_id'] = self.user_id.to_alipay_dict()
            else:
                params['user_id'] = self.user_id
        if self.user_id_type:
            if hasattr(self.user_id_type, 'to_alipay_dict'):
                params['user_id_type'] = self.user_id_type.to_alipay_dict()
            else:
                params['user_id_type'] = self.user_id_type
        if self.video_duration:
            if hasattr(self.video_duration, 'to_alipay_dict'):
                params['video_duration'] = self.video_duration.to_alipay_dict()
            else:
                params['video_duration'] = self.video_duration
        if self.video_play:
            if hasattr(self.video_play, 'to_alipay_dict'):
                params['video_play'] = self.video_play.to_alipay_dict()
            else:
                params['video_play'] = self.video_play
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayOpenMiniCloudAosbehaviorSyncModel()
        if 'action_type' in d:
            o.action_type = d['action_type']
        if 'channel' in d:
            o.channel = d['channel']
        if 'item_id_list' in d:
            o.item_id_list = d['item_id_list']
        if 'item_num' in d:
            o.item_num = d['item_num']
        if 'log_time' in d:
            o.log_time = d['log_time']
        if 'open_id' in d:
            o.open_id = d['open_id']
        if 'order_id' in d:
            o.order_id = d['order_id']
        if 'page_stay' in d:
            o.page_stay = d['page_stay']
        if 'pay_amount' in d:
            o.pay_amount = d['pay_amount']
        if 'pos' in d:
            o.pos = d['pos']
        if 'project_id' in d:
            o.project_id = d['project_id']
        if 'query' in d:
            o.query = d['query']
        if 'spm' in d:
            o.spm = d['spm']
        if 'trace_id' in d:
            o.trace_id = d['trace_id']
        if 'user_id' in d:
            o.user_id = d['user_id']
        if 'user_id_type' in d:
            o.user_id_type = d['user_id_type']
        if 'video_duration' in d:
            o.video_duration = d['video_duration']
        if 'video_play' in d:
            o.video_play = d['video_play']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class VoucherAvailableGoodsInfo(object):

    def __init__(self):
        self._available_goods_sku_ids = None
        self._exclude_goods_sku_ids = None
        self._goods_description = None
        self._goods_name = None
        self._origin_amount = None

    @property
    def available_goods_sku_ids(self):
        return self._available_goods_sku_ids

    @available_goods_sku_ids.setter
    def available_goods_sku_ids(self, value):
        if isinstance(value, list):
            self._available_goods_sku_ids = list()
            for i in value:
                self._available_goods_sku_ids.append(i)
    @property
    def exclude_goods_sku_ids(self):
        return self._exclude_goods_sku_ids

    @exclude_goods_sku_ids.setter
    def exclude_goods_sku_ids(self, value):
        if isinstance(value, list):
            self._exclude_goods_sku_ids = list()
            for i in value:
                self._exclude_goods_sku_ids.append(i)
    @property
    def goods_description(self):
        return self._goods_description

    @goods_description.setter
    def goods_description(self, value):
        self._goods_description = value
    @property
    def goods_name(self):
        return self._goods_name

    @goods_name.setter
    def goods_name(self, value):
        self._goods_name = value
    @property
    def origin_amount(self):
        return self._origin_amount

    @origin_amount.setter
    def origin_amount(self, value):
        self._origin_amount = value


    def to_alipay_dict(self):
        params = dict()
        if self.available_goods_sku_ids:
            if isinstance(self.available_goods_sku_ids, list):
                for i in range(0, len(self.available_goods_sku_ids)):
                    element = self.available_goods_sku_ids[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.available_goods_sku_ids[i] = element.to_alipay_dict()
            if hasattr(self.available_goods_sku_ids, 'to_alipay_dict'):
                params['available_goods_sku_ids'] = self.available_goods_sku_ids.to_alipay_dict()
            else:
                params['available_goods_sku_ids'] = self.available_goods_sku_ids
        if self.exclude_goods_sku_ids:
            if isinstance(self.exclude_goods_sku_ids, list):
                for i in range(0, len(self.exclude_goods_sku_ids)):
                    element = self.exclude_goods_sku_ids[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.exclude_goods_sku_ids[i] = element.to_alipay_dict()
            if hasattr(self.exclude_goods_sku_ids, 'to_alipay_dict'):
                params['exclude_goods_sku_ids'] = self.exclude_goods_sku_ids.to_alipay_dict()
            else:
                params['exclude_goods_sku_ids'] = self.exclude_goods_sku_ids
        if self.goods_description:
            if hasattr(self.goods_description, 'to_alipay_dict'):
                params['goods_description'] = self.goods_description.to_alipay_dict()
            else:
                params['goods_description'] = self.goods_description
        if self.goods_name:
            if hasattr(self.goods_name, 'to_alipay_dict'):
                params['goods_name'] = self.goods_name.to_alipay_dict()
            else:
                params['goods_name'] = self.goods_name
        if self.origin_amount:
            if hasattr(self.origin_amount, 'to_alipay_dict'):
                params['origin_amount'] = self.origin_amount.to_alipay_dict()
            else:
                params['origin_amount'] = self.origin_amount
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = VoucherAvailableGoodsInfo()
        if 'available_goods_sku_ids' in d:
            o.available_goods_sku_ids = d['available_goods_sku_ids']
        if 'exclude_goods_sku_ids' in d:
            o.exclude_goods_sku_ids = d['exclude_goods_sku_ids']
        if 'goods_description' in d:
            o.goods_description = d['goods_description']
        if 'goods_name' in d:
            o.goods_name = d['goods_name']
        if 'origin_amount' in d:
            o.origin_amount = d['origin_amount']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayIserviceCognitiveOcrVehicleplateQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayIserviceCognitiveOcrVehicleplateQueryResponse, self).__init__()
        self._error_content = None
        self._prob = None
        self._request_id = None
        self._success = None
        self._trace_id = None
        self._txt = None

    @property
    def error_content(self):
        return self._error_content

    @error_content.setter
    def error_content(self, value):
        self._error_content = value
    @property
    def prob(self):
        return self._prob

    @prob.setter
    def prob(self, value):
        self._prob = value
    @property
    def request_id(self):
        return self._request_id

    @request_id.setter
    def request_id(self, value):
        self._request_id = value
    @property
    def success(self):
        return self._success

    @success.setter
    def success(self, value):
        self._success = value
    @property
    def trace_id(self):
        return self._trace_id

    @trace_id.setter
    def trace_id(self, value):
        self._trace_id = value
    @property
    def txt(self):
        return self._txt

    @txt.setter
    def txt(self, value):
        self._txt = value

    def parse_response_content(self, response_content):
        response = super(AlipayIserviceCognitiveOcrVehicleplateQueryResponse, self).parse_response_content(response_content)
        if 'error_content' in response:
            self.error_content = response['error_content']
        if 'prob' in response:
            self.prob = response['prob']
        if 'request_id' in response:
            self.request_id = response['request_id']
        if 'success' in response:
            self.success = response['success']
        if 'trace_id' in response:
            self.trace_id = response['trace_id']
        if 'txt' in response:
            self.txt = response['txt']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.CarbonTrans import CarbonTrans


class AlipaySocialAntforestCarbondayQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipaySocialAntforestCarbondayQueryResponse, self).__init__()
        self._day_trans_list = None
        self._forest_open = None
        self._year = None

    @property
    def day_trans_list(self):
        return self._day_trans_list

    @day_trans_list.setter
    def day_trans_list(self, value):
        if isinstance(value, list):
            self._day_trans_list = list()
            for i in value:
                if isinstance(i, CarbonTrans):
                    self._day_trans_list.append(i)
                else:
                    self._day_trans_list.append(CarbonTrans.from_alipay_dict(i))
    @property
    def forest_open(self):
        return self._forest_open

    @forest_open.setter
    def forest_open(self, value):
        self._forest_open = value
    @property
    def year(self):
        return self._year

    @year.setter
    def year(self, value):
        self._year = value

    def parse_response_content(self, response_content):
        response = super(AlipaySocialAntforestCarbondayQueryResponse, self).parse_response_content(response_content)
        if 'day_trans_list' in response:
            self.day_trans_list = response['day_trans_list']
        if 'forest_open' in response:
            self.forest_open = response['forest_open']
        if 'year' in response:
            self.year = response['year']
